@@ -1,3 +1,5 @@
 pub use crate::lua_shared::*;
 pub use crate::types::{LuaCFunction, LuaInteger, LuaNumber, LuaState, LuaString};
-pub use crate::{cstr, rstr, printgm};
+
+pub use crate::util::dump_stack;
+pub use crate::{cstr, try_cstr, rstr, try_rstr, printgm, reg};
