@@ -13,10 +13,19 @@ pub type LuaState = *mut c_void; // Raw Lua state.
 pub type LuaCFunction = extern "C" fn(LuaState) -> c_int;
 
 #[repr(C)]
-pub struct LuaL_Buffer {
-	b: *mut i8,
-	size: SizeT,
-	n: SizeT, // number of chars in buffer
-	state: LuaState,
-	initbuffer: [i8; 8192_usize],
+pub struct LuaReg {
+	pub name: *const i8, // c_schar
+	pub func: Option<LuaCFunction>,
+}
+
+pub type LuaJITProfileCallback = extern "C" fn(data: *mut c_void, l: LuaState, samples: c_int, vmL: c_int) -> ();
+
+
+#[repr(C)]
+pub struct LuaBuffer {
+	pub b: *mut i8,
+	pub size: SizeT,
+	pub n: SizeT, // number of chars in buffer
+	pub state: LuaState,
+	pub initbuffer: [i8; 8192_usize],
 }
